@@ -28,7 +28,7 @@ class Timer : public QObject
     Q_PROPERTY(bool ringing READ ringing NOTIFY ringingChanged)
 
 public:
-    explicit Timer(QString uuid = QString{}, QObject *parent = nullptr);
+    explicit Timer(const QString &uuid = QString{}, QObject *parent = nullptr);
 
     const QUuid &uuid();
 
@@ -40,10 +40,10 @@ public:
     QString elapsedPretty() const;
 
     QString label() const;
-    void setLabel(QString label);
+    void setLabel(const QString &label);
 
     QString commandTimeout() const;
-    void setCommandTimeout(QString commandTimeout);
+    void setCommandTimeout(const QString &commandTimeout);
 
     bool running() const;
 
